<meta http-equiv="Content-Type" content="text/html; charset=utf-8">

<!-- Rendern mit
pandoc -f markdown+pipe_tables+grid_tables+multiline_tables+simple_tables+tex_math_dollars --mathml Einfuehrung.md -o Einfuehrung.html
-->

# Einführung in die Grundlagen der Elektrotechnik mit Matlab

Eine gute Referenz zur Einführung, zum Umgang mit Matlab bzw. Octave
findet man unter 
[Textbooks of Cleve Moler](https://www.mathworks.com/moler.html).
Schauen Sie sich die Einführungen dort an und vollziehen Sie die zum
Teil spannenden Experimente nach. Es hilft, Matlab/Octave zu erlernen
und die Schönheit der Mathematik zu verstehen.

## Ohmsches Gesetz und Widerstand

### Einstieg

* Berechnen Sie den Widerstand aus der gegebenen Spannung U und der
  Stromstärke I. 

	* *Lösung*
	
			# Beispielcode
			U=10
			I=1
			R=U/I
			# R=10

	
* Berechnen Sie (parallel) die Widerstandswerte bei mehreren Spannungs
  und Stromstärken

	* *Lösung*
	
			# Beispielcode
			U=[1 2 3 4];
			I=[4 3 2 1];
			R=U./I
			# R=[0.25 0.66 1.5 4]

### Zeichnen einer Geradenschar von Widerstandskennlinien

Zeichnen Sie eine Schar von Widerstandsgeraden in ein U-I
Diagramm. Entwerfen Sie eine Funktion, die mit den Eingaben
Umin,Umax,Rmin,Rmax jeweils die Geraden für zehn Widerstände im
Bereich Rmin und Rmax zeichnet.
	
* *Lösung*
	
	Die Kennlinien, inklusive der Nutzung einiger Features der
	Vektorrechnung findet man hier:
	
	[Berechnung von Widerstandskennlinien](r_kl.m)
	
	<!--
		% file: r_kl.m 
		% Berechnet eine Schar von Widerstandskennlinien
		function [retval] = r_kl (umin,umax, rmin,rmax)
		u=linspace(umin,umax,2);
		r=linspace(rmin,rmax,10);
		i=u./r';
		plot(u,i);
		grid on;
		xlabel('U/V');
		ylabel('I/A');
		legend(num2str(r'));
		end
	-->

### Berechnung der Geschwindigkeit der Ladungsträger im Leiter

Berechnen Sie die Geschwindigkeit von Ladungsträgern in einem
Leiter. Wie verhält sich die Geschwindigkeit zum Radius eines runden
Leiters? Wie dünn muss ein Kupferleiter werden, damit bei einer
Stromstärke von 1A die Elektronen Autogeschwindigkeit erreichen
(28m/s)?

* *Lösung*

	Die Geschwindigkeiten können mit dieser Funktion berechnet
    werden. 
		
	[Berechnung von Geschwindigkeiten von Ladungsträgern](e_v.m)
	
	<!--
		% file: e_v.m
		% Berechnet die Geschwindigkeit von Ladungsträgern 
		% in einem Leiter mit 
		% n (freie) Ladungsträgerdichte
		% I Stromstärke
		% A Querschnittsfläche
		function [v] = e_v (n,I,A)
		e=1.602e-19;
		v=I/(e*n*A)
		end
	-->
	
	Aufruf und Optimierung
	
		e_v(8.47e19*1e9,1,pi*(0.915e-6)^2)
	
	liefert als Geschwindigkeit in etwa 28m/s. Der Draht darf also nur
	einen Durchmesser von 1,8$\mu$m haben. Es ergibt sich dann eine
	Stromdichte von 

		1/(pi*(0.915e-6)^2)
		% 3.8020e+11A/m^2 = 380 kA/mm^2

	was ja ganz schön viel ist. Das zeigt einmal mehr, dass die Forderung 
	nach Autogeschwindigkeit für Elektronen im Kupfer unrealistisch ist, 
	denn das Material würde sofort verglühen.

	Die Darstellung der Geschwindigkeit über dem Radius kann mit 
	
		[Darstellung der Geschwindigkeit als Funktion des Radius](speed_vs_radius.m)

	<!--
		% file: speed_vs_radius.m
		% Berechnet die Gwschwindigkeit der Elektronen in Kupfer
		% für eine Reihe von Radien und plottet dieses dann
		% Eingaben sind Konstanten.
		%
		function speed_vs_radius
		n=8.47e19*1e9;
		I=1;
		r=10.^[-7:0.1:-3];
		v=[];
		for rr = r
			v=[v e_v(n,I,pi*rr^ 2)];
		end
		loglog(r*1000,v*1000); # Doppelt logarithmische Darstellung
		grid on;
		xlabel("r/mm");
		ylabel("v/(mm/s)");
		end
	-->
	
### Berechnung des Widerstandes eines langen geraden Leiters aus Geometrie und Materialparameter 

Erstellen Sie eine Funktion, die den Widerstand (von Kupfer) aus den
Materialparametern und der Geometrie, also Länge und Drahtdurchmesser
berechnet! Zeichnen Sie den Widerstand als Funktion des
Drahtdurchmessers in einem sinnvollen Bereich!

* *Lösung*

	Hier ist dann
	
	[Widerstand aus der Geometrie](widerstand.m)

	<!--
		% File: widerstand.m
		% Berechnung eines Widerstandes aus der Geometrie
		% rho: spezifischer Widerstand in Ohm*m
		% l: Länge des Drahtes in m (darf Vektor sein)
		% A: Querschnittsfläche in m^2 (darf Vektor sein)
		% wenn l und A Vektoren sind, müssen sie gleiche Länge aufweisen
		% Aufruf:
		% widerstand(material("Kupfer").rho,1000,1.5e-6)
		function r=widerstand(rho,l,A)
		r=rho*l./A;
		end
	-->
 
	Mit Zeichnung der Aufruf in einer Zeile

		d=[0.5:0.05:4]*1e-3;plot(d,widerstand(material("Kupfer").rho,1000,pi/4*d.^2));grid on; xlabel("d/m");ylabel("R/Ohm");

	Wobei hier eine Funktion material definiert war, die verschiedenen
    Materialparameter zurück liefert.

Berechnen Sie damit (analytisch oder ggf. durch Ausprobieren von
Zahlenwerten), wie lang ein Draht mit Widerstand 10Ohm bei einer
Querschnittsfläche von 1,5mm$^2$ sein muss! Warum sollte man so etwas
konstruieren wollen?

* *Lösung*

	Der Aufruf

		widerstand(material("Kupfer").rho,852.5,1.5e-6)
	
	würde das Problem lösen (R=10$\Omega$). Man macht so etwas eigentlich
	nicht, und wenn, dann damit sich der Draht auch bei großen
	Bemessungsströmen nicht erwärmt. Auf richtige Lages des Drahtes ist
	aber zu achten, bspw. nicht zu eng wickeln.

### Temperaturabhängigkeit des Widerstandes

Plotten Sie den Widerstand eines Materials (ggf. auch als Kurvenschar
mehrere Materialien) als Funktion der Temperatur, sinnvoller Bereich
ist bspw. -60°C bis 120°C (Automotive-Bereich) oder auch 20°C bis
500°C (Prozesstemperaturen).

### Stromdichte und erlaubte Ströme im Leiter

Berechnen Sie die Stromdichte in Kupferleitern für die nach VDE 0100
erlaubten Stromstärken in Abhängigkeit vom Drahquerschnitt. Warum ist
die erlaubte Stromstärke vom Drahtquerschnitt nicht unabhängig?

Erlaubt sind 

: Strombelastungen für ausgewählte Querschnitte

+-------------------+------------+-------------+
| Leiterquerschnitt | max. Strom | Stromdichte |
| - in mm^2         | - in A     | - in A/mm^2 |
+===================+============+=============+
|              0,75 |         13 |       17,3  |
+-------------------+------------+-------------+
|              1    |         16 |       16    |
+-------------------+------------+-------------+
|              1,5  |         20 |       13,33 |
+-------------------+------------+-------------+
|              2,5  |         27 |       10,8  |
+-------------------+------------+-------------+
|              4    |         36 |        9    |
+-------------------+------------+-------------+


## Spannungs und Stromquellen

Berechnen Sie die Kennlinien und Arbeitspunkte von Spannungs und Stromquellen
und stellen Sie diese dar. Sie können dieses für jeweils eine Quelle machen,
oder auch gleich vektororientiert angehen. Zudem ist die Zeichnung einer
Lastgerade hilfreich.

* *Lösung*

	[Parameter der Quellen werden hier dargestellt](quellen.m)

	<!--
  % File: quellen.m
  % Grafische Darstellung der Kennlinien von 
  % Strom- und Spannungsquellen inkl. 
  % der Kennlinie einer Last
  % ull: Leerlaufspannung (vektor)
  % iks: Kurzschlussstrom (vektor, gleiche Länge wie ull)
  % rl: Vektor von möglichen Lastwiderständen
  function [retval] = quellen (ull,iks,rl)
  u=[ull;zeros(1,length(ull))];
  i=[zeros(1,length(iks)); iks];
  clf;
  plot(u,i,'linewidth',4,'b-');
  hold on;  grid on;
  xlabel('U/V');  ylabel('I/A');
  ul=rl.*i;
  plot(ul,i,'r-','linewidth',4);
  axis([0 1.5 0 0.15]) % Evtl. auskommentieren!
  endfunction
  -->

## Schaltungen von Widerständen

### Reihen und Parallelschaltung

Geben Sie einen einfachen, einzeiligen Befehl zur Berechnung des
Gesamtwiderstandes von beliebig vielen Widerständen in Serie an! Die
Widerstande sind in dem Vektor "r" gespeichert

	rges=sum(r);
	
Geben Sie einen einfachen, einzeiligen Befehl zur Berechnung des
Gesamtwiderstandes von beliebig vielen parallelgeschalteten
Widerständen an! Die Widerstande sind in dem Vektor "r" gespeichert

	rges=1/sum(1./r);

### Stern <-> Dreiecksumwandlung

Erstellen Sie zwei Routinen, die diese Umwandlung, jede Routine eine
Richtung, ermöglichen. Versuche Sie, diese Routinen so zu
programmieren, dass Sie Vektoren von Stern oder Dreieckswiderständen
eingeben können. Damit können dann in einem Funktionsaufruf viele
Dreiecke und Sterne umgewandelt werden. Funktionieren Die Routinen,
wenn Sie die eine in die andere einsetzen?

* *Lösung*

	[Stern -> Dreieck](stern_dreieck.m)
	
	[Dreieck -> Stern](dreieck_stern.m)
	
	**Bemerkung:** Beachten Sie die Verwendung von Matrizen bei der
      vektoriellen Implementation.

## Netzwerkberechnung

Hier wird als einzig sinnvolles Verfahren nur das
Knotenpotenzialverfahren implementiert.

### Knoten-Potenzial-Verfahren

Implementieren Sie das Knotenpotenzialverfahren so, dass eine Netzliste
eingegeben werden kann. Es dürfen Anforderungen an die Syntax der
Netzliste gestellt werden und Fehler in dieser Syntax müssen nicht
abgefangen werden. 

Es ist sinnvoll zunächst den Aufbau der Netzliste zu definieren:

* *Lösung*
  Die Netzliste wird in einer separaten Datei vorgegeben. Sie besteht
  ausschließlich aus Zweigen, die alle wie folgt definiert sind:
  
: Definition der Parameter der Netzliste

+--------+-------------+------------------------------+
| Spalte | Bezeichnung | Beschreibung                 |
+========+=============+==============================+
|      1 | Knoten 1    | positiver der beiden Knoten  |
+--------+-------------+------------------------------+
|      2 | Knoten 2    | negativer der beiden Knoten  |
+--------+-------------+------------------------------+
|      3 | R           | Widerstand zwischen Knoten   |
+--------+-------------+------------------------------+
|      4 | I           | Quellenstrom parallel zu R   |
+--------+-------------+------------------------------+
|      5 | V           | Quellenspannung seriell zu R |
+--------+-------------+------------------------------+
  
  Randbedingungen: 
	  * Es muss einen Knoten 0 (Masseknoten) geben, Alle Knotennummern
        von 0 bis Kmax müssen vorhanden sein, Kmax definiert dann die
        Anzahl der Knoten (+1)
	  * R darf nicht Null sein (ideale Spannungsquelle)
	  * I und V dürfen Null sein, Vorzeichen ist so, dass der Pluspol
  einer Quelle an Knoten 1 liegen würde.
  
  [Beispielnetzliste nach Übungsaufgabe 6.1](kpv_aufg6p1.txt)

Stellen Sie nun die Leitwertmatrix, und den Vektor der Quellenströme
auf, lassen Sie das Gleichungssystem lösen und geben Sie die
Knotenspannungen aus! Zum Schluss berechnen Sie noch die Ströme durch
die in der Netzliste definierten Widerstände R!

* *Lösung*

	[Knotenpotenzialverfahren](kpv.m)
	
	* Es wird zunächst eine Matrix mit Kantenlänge Kmax aufgestellt
    und mit Nullen gefüllt
	* Für jeden Netzeintrag werden dann die Elemente auf der
      Diagonale, die zu den beiden Knoten gehören, um den jeweiligen
      Leitwert erhöht.
	* Die beiden Neben-Diagonal (Koppel) Elemente werden um den
      Leitwert erniedrigt (negativ eben)
	* Auf der rechten Seite werden die Quellenströme eintragen. Bei
      beiden Knoten der angegebene Strom und der äquivalente
      Quellenstrom aus der Spannungsquelle. Positiv in Knoten 1,
      negativ in Knoten 2
	* Das LGS wird gelöst, die Knotenspannungen stehen direkt zur
      Verfügung
	* Stromstärken durch die Widerstände werden separat nach Maßgabe
      der Netzliste berechnet. Ggf. muss der Spannungsabfall über dem
      Widerstand auf der Potenzialdifferenz zwischen den Knoten und
      der Quellenspannung im Zweig berechnet werden.

## Nichtlineare Kreise

Bestimmen eines Arbeitspunktes bei einem nichtlinearen an einem
ansonsten linearen Zweitor ist im Prinzip die Suche einer
Nullstelle. Grafisch erfolgt das so, dass der Schnittpunkt der
Arbeitsgerade des linearen Zweitores (Ersatzquelle) mit der
nichtlinearen Kennlinie gesucht wird. Mathematisch bildet man einfach
die Differenz von beiden und sucht die Nullstelle. In Octave ist eine
mögliche Funktion 

 y=fzero(f,[xmin,xmax])
 
wobei mit 
 
 f=@(x) x*x-1;
 
irgendeine (anonyme) Funktion definiert wird und xmin,xmax ein
Intervall darstellen, in dem ein Vorzeichenwechsel der Funktion
vorliegen muss.

Versuchen Sie sich mit dieser einfach Konstruktion, lernen Sie etwas
über anonyme Funktionen in Octave, die Syntax müssen Sie verstehen,
sonst wird es später schwierig.

### Diodenkennlinie

Eine Diodenkennlinie ist im idealen/ einfachen Fall gegeben über die
Shockley-Gleichung

$$I_D(U)=I_S(e^{U/U_T}-1)$$

mit dem Sperrstrom $I_S$ typischerweise femto oder nano Ampere, und
$U_T=25$mV der Temperaturspannung. Die Herleitung lassen wir hier weg,
Sie können diese in einem Elektronikbuch oder auch Wikipedia finden.

Programmieren Sie eine anonyme Funktion der Shockley-Gleichung und
plotten Sie diese!

Bestimmen Sie den Arbeitspunkt einer Diode mit o.g. Kennlinie (nehmen
Sie Werte für $I_S$ an) an einer Spannungsquelle mit Innenwiderstand.

* *Lösung*

	[Arbeitspunkt bei nichtlinearer Kennlinie](nl_ap.m)
	
	Es wird die Maschengleichung so umgeformt, dass
	* es nur eine Funktion von $U_{NL}$ ist
	* Sie Null ergeben muss, damit die Nullstellensuche auch
      funktionieren kann.
	
	**Bemerkung:** Die Reihenfolge der Rückgabeparameter wird im
      Folgenden wichtig sein. Iap muss der erste Parameter sein!

### Verschiedene LED-Kennlinien

Dioden haben typischerweise eine Schwellen/Durchlassspannung (das ist die Spannung
ab der der Strom dramatisch steigt) von 0,7V. LED haben eine solche,
die der Energie der der Photonen, die die emittieren, entspricht. Das
sind bei Rot etwa 1,8V, bei gelb 2,1V, bei grün 2,4V, bei blau
3V. Dieses alles sind ungefähre Angaben, es kommt natürlich auf die
exakte Farbe bzw. Wellenlänge des Lichts an.

Variieren Sie den Sperrstrom so, dass Sie unterschiedliche
Durchlassspannungen einstellen können.

* *Lösung*
  
  Zur Lösung nur so viel, dass es bei Verwendung der o.g. Kennlinie
  unrealistisch geringe Werte für den Sperrstrom sind. Dieser
  Widerspruch wird hier nicht aufgelöst.


### Bestimmung des Vorwiderstandes

Verwenden Sie die vorstehende Routine zur Bestimmung des
Arbeitspunktes, um den Vorwiderstand zu bestimmen!

* *Lösung* 

	Hier wird die Berechnung der Stromstärke im Arbeitspunkt
    verwendet, um eine weitere Funktion auf zu bauen, nämlich
	
	$$I_{AP}-I_{soll}=0$$
	
	Und da $I_{AP}$ vom Vorwiderstand abhängt, wird dieser so lange
    variiert, bis o.g. Gleichung Null ergibt. Das Ergebnis ist der
    Vorwiderstand. 
	
	[Bestimmung des Vorwiderstandes](nl_ap_rv.m)

## Anfangs- und Endzustände/ Schaltzustände

### Lösung der Kondensator/ Spulen DGL, 

Berechnen Sie Verlauf der Spannung und der Stromstärke über bzw. durch
einen Kondensator und eine Spule. Das Element wird jeweils aus einer
Spannungsquelle gespeist und ist an diese über einen Widerstand
$R_1$ angeschlossen. Die Entladung erfolgt über einen Widerstand
$R_2$. Experimentieren Sie mit verschiedenen Verhältnissen der
Widerstände und der Zeitkonstanten $L/R$ bzw. $RC$ und entsprechend der
Zeiten für Ladung und für Entladung!

* *Lösung*

	Für die Theorie wird auf die Vorlesung, bzw. die Video-Clips
    verwiesen. Die Grafiken und Lösungen findet man hier:

	[Ladevorgänge an einer Kapazität](cap1.m)
	
	[Ladevorgänge an einer Induktivität](ind1.m)

### Lösung gewöhnlicher Differentialgleichungen

Die Lösung von Differentialgleichungen (Ordinary Differential
Equations (ODE)) kann auch numerisch in Octave erfolgen. Dazu muss die
Gleichung immer in die Form 

$$ \dot{x}=\frac{dx}{dt}=f(x) $$

gebracht werden. Der Punkt über der Variablen ist eine Abkürzung für
die Ableitung nach der Zeit. 

### Berechnung der Ladekurve an einem RC-Glied

Für die Masche bestehend aus Spannungsquelle, Widerstand und
Kondensator folgt dann

$$\dot{u_c}=\frac{1}{RC}(U_q-u_c)$$

und als kurzes Matlabprogramm

    # Beispielcode
	R=1000; C=1e-6; Uq=1; t=R*C;
    t=linspace(0,5*t,1001);
    ucdot=@(uc,t) (Uq-uc)/(R*C);
    uc=lsode(ucdot,0,t);
 
erhält man im Ergebnis den zeitlichen Verlauf der Spannung am
Kondensator. erstellen Sie ein Programm, bei dem die Anregung uq eine
von Ihnen vorgegebene Form hat (bspw. Sinus oder Rechteck) und die
Stromstärke berechnet wird und alles zusammen gezeichnet wird.

* *Lösung*

	[Ladekurve eines RC-Gliedes](cap_lade1.m)
 
### Berechnung der Ladekurve an einem LR-Glied

Wiederholen Sie o.g. Aufgabe und modifizieren Sie sie so, dass die
entsprechenden Parameter bei Anschluss einer Spule an eine Spannungs
(oder Stromquelle) berechnet werden!

* *Lösung*

Es muss die modifizierte DGL aufgestellt werden, die hier direkt für
den Strom löst. Dann erhält man

	[Ladekurve eines LR-Gliedes](ind_lade1.m)

### Berechnungen an zwei RC-Gliedern

Betrachten Sie noch einmal den o.g. Kreis zur Berechnung des
Spannungsverlaufs an einer Kapazität $C_1$, die von einer
Spannungsquelle $U_Q$ mit Innenwiderstand $R_1$ gespeist
wird. Parallel zur Kapazität $C_1$ wird ein weitere RC-Glied mit
$C_1,R_1$ geschaltet. 

Leiten Sie das System der Differentialgleichungen her und lösen Sie es
mit Octave.

* *Lösung*

	Siehe Video [Herleitung des DGL-Systems für zwei RC-Glieder]()
	
	[Zwei RC-Glieder](cap_lade2.m)

### RLC-Resonanzkreis

Nun sind an einer Spannungsquelle RL und C in Serien
angebracht. Dieses nennt man den Serienschwingkreis. 

Stellen Sie das System von DGL auf und lösen Sie in Octave, so dass
die Spannungen an den einzelnen Elementen gefunden werden!

* *Lösung*

	Die DGL zweiter Ordnung ist durch die Maschengleichung schnell
    aufgestellt und lautet
	
	$$U_Q=Ri+L\frac{di}{dt}+\frac{q}{C}$$
	
	was etwas unhandlich ist, da mit $q$ nun auch noch das Integral
    des Stromes auftaucht. Daher wird alles auf $q$ umgeschrieben:
	
	$$U_Q-R\frac{dq}{dt}-L\frac{d^2q}{dt^2}-\frac{q}{C}=0$$
	
	oder
	
	$$\frac{d^2q}{dt^2}=\frac{U_Q}{L}-\frac{R}{L}\frac{dq}{dt}-\frac{q}{LC}$$
	
	Damit hat man eine DGL zweiter Ordnung, die aber Octave nicht
    verarbeiten kann, man braucht ein System von DGL erster
    Ordnung. Wenn man nun einen Vektor mit $q_1$ und $q_2$ definiert
    und dort
	
	$$\frac{dq_1}{dt}=q_2$$
	
	$$\frac{dq_2}{dt}=\frac{U_Q}{L}-\frac{q_1}{LC}-\frac{R}{L}q_2$$
	
	Die linken Seiten sind das berühmte qdot (xdot), das in Octave
    definiert werden muss, und rechts steht die Funktion f(x). Damit
    ist die entscheidende Zeile
	
        qdot=@(q,t) [q(2);uq(t)/L-q(1)/(L*C)-R/L*q(2)]
		
	[Die Herleitung im Video ist]()

	Das komplette Programm findet sich unter
	
	[Serienresonanzkreis](rlc1.m)
