%
% Berechnet die Ladekurve einer einfachen LR-Kompbination
%
%    +-R--+
%    |    |
%    U    L
%    |    |
%    +----+
%
% R: Widerstand
% L: Induktivität
% U: Quellenspannung
% t: Stopzeit
%
% Ausgabe
% t das Zeitfeld
% ul Spannung über Induktivität
% ig Strom
%
% Beispielaufruf
% [t,ul,ig]=ind_lade1(10,1e-3,1,5e-4);

function [t,ul,ig] = ind_lade1 (R,L,U,t)
t=linspace(0,t,1001);
% Definition der Spannungsquelle
%uq=@(t) U;
uq=@(t) U*sin(t*R/L);
%uq=@(t) U/2*sign(sin(2*pi*t*R/L))+U/2;
% Definition der ODE
igdot=@(ig,t) (uq(t)-ig*R)/L;
ig=lsode(igdot,0,t);
ul=uq(t)-ig'*R;
figure(1); clf; hold on;
[ax,h1,h2]=plotyy(t,ul,t,ig); hold on;
set(h1,'linewidth',4);set(h2,'linewidth',4);
set(h1,'color','b');set(h2,'color','r');
set(ax(2),'ycolor',[1 0 0]);set(ax,'fontsize',16);
xlabel('t/s');ylabel(ax(1),'u/V');ylabel(ax(2),'i/A');
grid on;
endfunction
