%
% Berechnet die Spannung/Ladungen/Stromstärken an einem
% RLC-Serienresonanzkreis
%
%    +-R--L--C--+
%    |          |
%    U          |
%    |          |
%    +----------+
%
% R: Widerstand
% L: Induktivität
% C: Kapazität
% U: Quellenspannung
% t: Stopzeit
%
% Ausgabe
% t das Zeitfeld
% urlc Spannungen über den Elementen
% irlc Stromstärke
% qrlc Ladung auf der Kapazität
%
% Beispielaufruf
% [t,urlc,irlc,qrlc]=rlc1(1,1e-3,1e-5,1,1e-3);

function [t,urlc,irlc,qrlc] = rlc1 (R,L,C,U,t)
t=linspace(0,t,1001);
% Definition der Spannungsquelle
uq=@(t) U;
uq=@(t) U*cos(t/sqrt(L*C));
%uq=@(t) U/2*sign(sin(0.1*t/sqrt(L*C)))+0*U/2;
uq
% Definition der ODE
qdot=@(q,t) ...
  [q(2);...
    uq(t)/L-q(1)/(L*C)-R/L*q(2)]
qc=lsode(qdot,[0 0],t); % Lösung der ODE
qrlc=qc(:,1); % Ladung
irlc=qc(:,2); % Stromstärke
urlc=zeros(length(t),3);
urlc(:,3)=qrlc/C; % Spannung an C
urlc(:,1)=irlc*R; % Spannung an R
urlc(:,2)=uq(t)'-urlc(:,1)-urlc(:,3); % Spannung an L
figure(1); clf; hold on;
plot(t,urlc(:,1),'r-','linewidth',4);
plot(t,urlc(:,2),'b-','linewidth',4);
plot(t,urlc(:,3),'g-','linewidth',4);
plot(t,uq(t),'k-','linewidth',2);
xlabel('t/s');ylabel('u/V');
legend('U_R','U_L','U_C','U_Q');
grid on;
endfunction
